@@ -16,16 +16,15 @@ from wrdice.Battle import Battle
 from wrdice.config import *
 import sys
 
-def start_sim(in_, out_):
-    asyncio.run(Simulator(in_, out_))
+def start_sim(in_, out_, q_intermediate):
+    asyncio.run(Simulator(in_, out_, q_intermediate))
 
-def Simulator(q_in, q_out):
+def Simulator(q_in, q_out, q_intermediate):
     sim = Simulate(None, None)
     print('Starting Simulator Process')
     while True:
         #n = q_in.coro_get()
         n = q_in.get()
-        print('.')
         if n == 'EXIT':
             print('exit')
             sys.exit()
@@ -36,7 +35,7 @@ def Simulator(q_in, q_out):
             army_a = n[2]
             army_b = n[3]
             sim.reset()
-            msg = sim.run_all(combat_system, config, army_a, army_b)
+            msg = sim.run_all(combat_system, config, army_a, army_b, q_intermediate)
         q_out.put(msg)
 
 class Simulate:
@@ -87,7 +86,7 @@ class Simulate:
                 self.battle_type = 'sea'
         
 
-    def run_all(self, combat_system: CombatSystem, config=None,  armyA: Optional[Army]=None, armyB: Optional[Army]=None) -> StringIO:
+    def run_all(self, combat_system: CombatSystem, config=None,  armyA: Optional[Army]=None, armyB: Optional[Army]=None, q_intermediate=None) -> StringIO:
         if armyA is not None:
             self.army_a = armyA
         if armyB is not None:
@@ -95,7 +94,7 @@ class Simulate:
 
         self.update_battle_type()
 
-        ret = self.run(combat_system, config)
+        ret = self.run(combat_system, config, q_intermediate)
         if ret:
             self.eval_statistics()
             msg = self.get_report()
@@ -135,7 +134,7 @@ class Simulate:
 
 
 
-    def run(self, combat_system: CombatSystem, config=None) -> bool:
+    def run(self, combat_system: CombatSystem, config=None, q_intermediate=None) -> bool:
         troops_a, troops_b = 0, 0
         for T in ['sea', 'land', 'air']:
             troops_a += self.army_a.units[T].sum() 
@@ -174,8 +173,26 @@ class Simulate:
                         self.survivors[side][type][-1][0] += battle.army[side].submerged
             if abrt:
                 break
+
+            if n % 50 == 0 and q_intermediate is not None:
+                q_intermediate.put(self.intermediate_statistics())
         return True
 
+    def intermediate_statistics(self):
+        self.stats[status] += 1
+        N = (self.cur_n + 1)
+        x = self.stats / N
+
+        report = StringIO(newline=os.linesep)
+
+        report.write(f"Results:{os.linesep}")
+        report.write(f"{'A Won:':<20}{x[0] / N:.2f}{os.linesep}")
+        report.write(f"{'B Won:':<20}{x[1] / N:.2f}{os.linesep}") 
+        report.write(f"{'Draw:':<20}{x[2]  / N:.2f}{os.linesep}")
+        report.write(f"{'Mutual Annihilation:':<20}{x[3] / N:.2f}{os.linesep}")
+
+        return report.getvalue()
+
 
     def eval_statistics(self):
         # eval
@@ -284,7 +301,7 @@ class Simulate:
                 # append air
                 str += f"{data['variations'][i][5+COLOR.GREEN]:<10}"
                 str += f"{data['variations'][i][5+COLOR.RED]:<10}"
-                buf.write(str+os.linesep)
+                buf.write(str+os.linesep
             return buf.getvalue()
 
         def print_legend() -> str:
