@@ -18,7 +18,7 @@ if __name__ == '__main__':
     NO_UNIT = [0,0,0,0,0]
     ALL_UNITS = [-1,-1,-1,-1,-1]
 
-    B = Army(units_land = [3,2,1,0,0], 
+    B = Army(units_land = [4,2,0,0,0], 
              units_air =  [0,0,0,0,0], 
              units_sea =  [0,0,0,0,0],
              options = config)
@@ -27,12 +27,12 @@ if __name__ == '__main__':
                     stance_sea = [NO_UNIT,      ALL_UNITS])
 
 
-    A = Army(units_land = [0,0,4,0,0], 
+    A = Army(units_land = [0,2,0,0,0], 
              units_air =  [0,0,0,0,0], 
              units_sea =  [0,0,0,0,0],
              options = config)
 
-    A.apply_stance(stance_land = [[0,0,0,0,0], [0,0,-1,0,0]],
+    A.apply_stance(stance_land = [[0,0,0,0,0], [0,-1,-1,0,0]],
                     stance_air = [NO_UNIT,      ALL_UNITS],
                     stance_sea = [ALL_UNITS,    NO_UNIT])
     
